pub struct AuditConfig {
pub enabled: bool,
pub max_size: u64,
pub max_files: u32,
}Expand description
Configuration for the audit log.
Fields
enabled: boolEnable audit logging (default: true).
max_size: u64Maximum audit log file size in bytes before rotation (default: 50 MB).
max_files: u32Maximum number of rotated audit log files to keep (default: 10).