pub struct NormalizedComposeConfig {
pub services: BTreeMap<String, NormalizedServiceConfig>,
pub volumes: BTreeMap<String, NormalizedVolumeDeclaration>,
pub networks: BTreeMap<String, NormalizedNetworkDeclaration>,
}Expand description
Deterministic, syntax-independent Compose project model.
All semantic maps use BTreeMap, alternate list/map spellings are collapsed
into one representation, and supported driver defaults are explicit.
Fields
services: BTreeMap<String, NormalizedServiceConfig>Canonically ordered service definitions.
volumes: BTreeMap<String, NormalizedVolumeDeclaration>Canonically ordered named volume declarations.
networks: BTreeMap<String, NormalizedNetworkDeclaration>Canonically ordered named network declarations.
Implementations
Sourceimpl NormalizedComposeConfig
impl NormalizedComposeConfig
Sourcepub fn to_canonical_json(&self) -> Result<String, Error>
pub fn to_canonical_json(&self) -> Result<String, Error>
Serialize a byte-stable, pretty JSON representation with a final newline.
Sourcepub fn service_order(&self) -> Result<Vec<String>, ComposeNormalizationError>
pub fn service_order(&self) -> Result<Vec<String>, ComposeNormalizationError>
Compute a deterministic dependency-first service order.
Sourcepub fn into_config(self) -> ComposeConfig
pub fn into_config(self) -> ComposeConfig
Convert the canonical model into the compatibility model consumed by the current Runtime translation layer.