pub enum FilesystemEntryKind {
Unspecified,
File,
Directory,
}Expand description
Entry type returned by a workload filesystem operation.
Variants
Unspecified
Entry type could not be represented by the pinned contract.
File
Regular file, or a symlink whose target is a regular file.
Directory
Directory, or a symlink whose target is a directory.