Module execution

Module execution 

Backend-neutral execution isolation resolution.

Structs

ResolvedExecutionPlan
Deterministic result of resolving one execution request.

Enums

ExecutionBackend
Concrete backend selected for an execution request.
IsolationClass
Security boundary provided by the resolved backend.

Functions

resolve_execution
Resolve a box configuration without probing or mutating the host.
validate_microvm_compatibility
Validate features that cannot be represented safely by the MicroVM backend.
validate_sandbox_compatibility
Validate features that cannot be represented safely by the sandbox MVP.