pub struct NetworkInstanceConfig {
pub net_socket_path: PathBuf,
pub net_stats_path: Option<PathBuf>,
pub net_socket_fd: Option<RawFd>,
pub net_proxy_fd: Option<RawFd>,
pub bridge_socket_dir: Option<PathBuf>,
pub ip_address: Ipv4Addr,
pub gateway: Ipv4Addr,
pub prefix_len: u8,
pub mac_address: [u8; 6],
pub dns_servers: Vec<Ipv4Addr>,
}Expand description
Network instance configuration for the network backend (passt on Linux, gvproxy on macOS).
Fields
net_socket_path: PathBufPath to the network backend Unix socket (passt on Linux, gvproxy on macOS).
net_stats_path: Option<PathBuf>Optional JSON stats file written by the userspace network backend.
net_socket_fd: Option<RawFd>Pre-opened network socket fd inherited by the shim on Unix.
net_proxy_fd: Option<RawFd>Proxy-side network socket fd inherited by the shim on Unix.
bridge_socket_dir: Option<PathBuf>Shared Unix-datagram Ethernet switch directory for this bridge network.
ip_address: Ipv4AddrAssigned IPv4 address for this VM.
gateway: Ipv4AddrGateway IPv4 address.
prefix_len: u8Subnet prefix length (e.g., 24).
mac_address: [u8; 6]MAC address as 6 bytes.
dns_servers: Vec<Ipv4Addr>DNS servers to configure inside the guest.