Backend-neutral execution isolation resolution.
Structs
- Resolved
Execution Plan - Deterministic result of resolving one execution request.
Enums
- Execution
Backend - Concrete backend selected for an execution request.
- Isolation
Class - Security boundary provided by the resolved backend.
Functions
- resolve_
execution - Resolve a box configuration without probing or mutating the host.
- validate_
microvm_ compatibility - Validate features that cannot be represented safely by the MicroVM backend.
- validate_
sandbox_ compatibility - Validate features that cannot be represented safely by the sandbox MVP.